@@ -1,7 +1,8 @@
-pub mod traits;
-use traits::Cash;
-use traits::create::*;
-use traits::calculate::*;
+mod structs;
+mod traits;
+use crate::structs::cash::Cash;
+use crate::structs::cash::create::Procedures;
+use crate::structs::cash::calculate::Operations;
 
 fn cristi() {
     let wallet: Cash = Cash::create(String::from("eur"), 2);
